@@ -3,7 +3,6 @@
  * Copyright (c) 1996-1999 by Silicon Graphics.  All rights reserved.
  * Copyright (c) 2003-2011 Hewlett-Packard Development Company, L.P.
  *
- *
  * THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY EXPRESSED
  * OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.
  *
@@ -12,9 +11,14 @@
  * Permission to modify the code and to distribute modified code is granted,
  * provided the above notices are retained, and a notice that the code was
  * modified is included with the above copyright notice.
- *
  */
 
+#if !defined(AO_ATOMIC_OPS_H) || defined(AO_ATOMIC_OPS_INCLUDED)
+# error This file should not be included directly.
+#endif
+
+#ifndef AO_NO_char_ARITHM
+
 AO_INLINE unsigned/**/char
 AO_char_fetch_and_add(volatile unsigned/**/char *addr, unsigned/**/char incr)
 {
@@ -48,12 +52,13 @@ AO_char_fetch_and_add(volatile unsigned/**/char *addr, unsigned/**/char incr)
   }
 # define AO_HAVE_char_xor
 #endif
+
+#endif /* !AO_NO_char_ARITHM */
 /*
  * Copyright (c) 1991-1994 by Xerox Corporation.  All rights reserved.
  * Copyright (c) 1996-1999 by Silicon Graphics.  All rights reserved.
  * Copyright (c) 2003-2011 Hewlett-Packard Development Company, L.P.
  *
- *
  * THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY EXPRESSED
  * OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.
  *
@@ -62,9 +67,14 @@ AO_char_fetch_and_add(volatile unsigned/**/char *addr, unsigned/**/char incr)
  * Permission to modify the code and to distribute modified code is granted,
  * provided the above notices are retained, and a notice that the code was
  * modified is included with the above copyright notice.
- *
  */
 
+#if !defined(AO_ATOMIC_OPS_H) || defined(AO_ATOMIC_OPS_INCLUDED)
+# error This file should not be included directly.
+#endif
+
+#ifndef AO_NO_short_ARITHM
+
 AO_INLINE unsigned/**/short
 AO_short_fetch_and_add(volatile unsigned/**/short *addr, unsigned/**/short incr)
 {
@@ -98,12 +108,13 @@ AO_short_fetch_and_add(volatile unsigned/**/short *addr, unsigned/**/short incr)
   }
 # define AO_HAVE_short_xor
 #endif
+
+#endif /* !AO_NO_short_ARITHM */
 /*
  * Copyright (c) 1991-1994 by Xerox Corporation.  All rights reserved.
  * Copyright (c) 1996-1999 by Silicon Graphics.  All rights reserved.
  * Copyright (c) 2003-2011 Hewlett-Packard Development Company, L.P.
  *
- *
  * THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY EXPRESSED
  * OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.
  *
@@ -112,9 +123,14 @@ AO_short_fetch_and_add(volatile unsigned/**/short *addr, unsigned/**/short incr)
  * Permission to modify the code and to distribute modified code is granted,
  * provided the above notices are retained, and a notice that the code was
  * modified is included with the above copyright notice.
- *
  */
 
+#if !defined(AO_ATOMIC_OPS_H) || defined(AO_ATOMIC_OPS_INCLUDED)
+# error This file should not be included directly.
+#endif
+
+#ifndef AO_NO_int_ARITHM
+
 AO_INLINE unsigned
 AO_int_fetch_and_add(volatile unsigned *addr, unsigned incr)
 {
@@ -148,12 +164,13 @@ AO_int_fetch_and_add(volatile unsigned *addr, unsigned incr)
   }
 # define AO_HAVE_int_xor
 #endif
+
+#endif /* !AO_NO_int_ARITHM */
 /*
  * Copyright (c) 1991-1994 by Xerox Corporation.  All rights reserved.
  * Copyright (c) 1996-1999 by Silicon Graphics.  All rights reserved.
  * Copyright (c) 2003-2011 Hewlett-Packard Development Company, L.P.
  *
- *
  * THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY EXPRESSED
  * OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.
  *
@@ -162,9 +179,14 @@ AO_int_fetch_and_add(volatile unsigned *addr, unsigned incr)
  * Permission to modify the code and to distribute modified code is granted,
  * provided the above notices are retained, and a notice that the code was
  * modified is included with the above copyright notice.
- *
  */
 
+#if !defined(AO_ATOMIC_OPS_H) || defined(AO_ATOMIC_OPS_INCLUDED)
+# error This file should not be included directly.
+#endif
+
+#ifndef AO_NO_ARITHM
+
 AO_INLINE AO_t
 AO_fetch_and_add(volatile AO_t *addr, AO_t incr)
 {
@@ -198,12 +220,13 @@ AO_fetch_and_add(volatile AO_t *addr, AO_t incr)
   }
 # define AO_HAVE_xor
 #endif
+
+#endif /* !AO_NO_ARITHM */
 /*
  * Copyright (c) 1991-1994 by Xerox Corporation.  All rights reserved.
  * Copyright (c) 1996-1999 by Silicon Graphics.  All rights reserved.
  * Copyright (c) 2003-2011 Hewlett-Packard Development Company, L.P.
  *
- *
  * THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY EXPRESSED
  * OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.
  *
@@ -212,9 +235,14 @@ AO_fetch_and_add(volatile AO_t *addr, AO_t incr)
  * Permission to modify the code and to distribute modified code is granted,
  * provided the above notices are retained, and a notice that the code was
  * modified is included with the above copyright notice.
- *
  */
 
+#if !defined(AO_ATOMIC_OPS_H) || defined(AO_ATOMIC_OPS_INCLUDED)
+# error This file should not be included directly.
+#endif
+
+#ifndef AO_NO_char_ARITHM
+
 AO_INLINE unsigned/**/char
 AO_char_fetch_and_add_acquire(volatile unsigned/**/char *addr, unsigned/**/char incr)
 {
@@ -248,12 +276,13 @@ AO_char_fetch_and_add_acquire(volatile unsigned/**/char *addr, unsigned/**/char
   }
 # define AO_HAVE_char_xor_acquire
 #endif
+
+#endif /* !AO_NO_char_ARITHM */
 /*
  * Copyright (c) 1991-1994 by Xerox Corporation.  All rights reserved.
  * Copyright (c) 1996-1999 by Silicon Graphics.  All rights reserved.
  * Copyright (c) 2003-2011 Hewlett-Packard Development Company, L.P.
  *
- *
  * THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY EXPRESSED
  * OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.
  *
@@ -262,9 +291,14 @@ AO_char_fetch_and_add_acquire(volatile unsigned/**/char *addr, unsigned/**/char
  * Permission to modify the code and to distribute modified code is granted,
  * provided the above notices are retained, and a notice that the code was
  * modified is included with the above copyright notice.
- *
  */
 
+#if !defined(AO_ATOMIC_OPS_H) || defined(AO_ATOMIC_OPS_INCLUDED)
+# error This file should not be included directly.
+#endif
+
+#ifndef AO_NO_short_ARITHM
+
 AO_INLINE unsigned/**/short
 AO_short_fetch_and_add_acquire(volatile unsigned/**/short *addr, unsigned/**/short incr)
 {
@@ -298,12 +332,13 @@ AO_short_fetch_and_add_acquire(volatile unsigned/**/short *addr, unsigned/**/sho
   }
 # define AO_HAVE_short_xor_acquire
 #endif
+
+#endif /* !AO_NO_short_ARITHM */
 /*
  * Copyright (c) 1991-1994 by Xerox Corporation.  All rights reserved.
  * Copyright (c) 1996-1999 by Silicon Graphics.  All rights reserved.
  * Copyright (c) 2003-2011 Hewlett-Packard Development Company, L.P.
  *
- *
  * THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY EXPRESSED
  * OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.
  *
@@ -312,9 +347,14 @@ AO_short_fetch_and_add_acquire(volatile unsigned/**/short *addr, unsigned/**/sho
  * Permission to modify the code and to distribute modified code is granted,
  * provided the above notices are retained, and a notice that the code was
  * modified is included with the above copyright notice.
- *
  */
 
+#if !defined(AO_ATOMIC_OPS_H) || defined(AO_ATOMIC_OPS_INCLUDED)
+# error This file should not be included directly.
+#endif
+
+#ifndef AO_NO_int_ARITHM
+
 AO_INLINE unsigned
 AO_int_fetch_and_add_acquire(volatile unsigned *addr, unsigned incr)
 {
@@ -348,12 +388,13 @@ AO_int_fetch_and_add_acquire(volatile unsigned *addr, unsigned incr)
   }
 # define AO_HAVE_int_xor_acquire
 #endif
+
+#endif /* !AO_NO_int_ARITHM */
 /*
  * Copyright (c) 1991-1994 by Xerox Corporation.  All rights reserved.
  * Copyright (c) 1996-1999 by Silicon Graphics.  All rights reserved.
  * Copyright (c) 2003-2011 Hewlett-Packard Development Company, L.P.
  *
- *
  * THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY EXPRESSED
  * OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.
  *
@@ -362,9 +403,14 @@ AO_int_fetch_and_add_acquire(volatile unsigned *addr, unsigned incr)
  * Permission to modify the code and to distribute modified code is granted,
  * provided the above notices are retained, and a notice that the code was
  * modified is included with the above copyright notice.
- *
  */
 
+#if !defined(AO_ATOMIC_OPS_H) || defined(AO_ATOMIC_OPS_INCLUDED)
+# error This file should not be included directly.
+#endif
+
+#ifndef AO_NO_ARITHM
+
 AO_INLINE AO_t
 AO_fetch_and_add_acquire(volatile AO_t *addr, AO_t incr)
 {
@@ -398,12 +444,13 @@ AO_fetch_and_add_acquire(volatile AO_t *addr, AO_t incr)
   }
 # define AO_HAVE_xor_acquire
 #endif
+
+#endif /* !AO_NO_ARITHM */
 /*
  * Copyright (c) 1991-1994 by Xerox Corporation.  All rights reserved.
  * Copyright (c) 1996-1999 by Silicon Graphics.  All rights reserved.
  * Copyright (c) 2003-2011 Hewlett-Packard Development Company, L.P.
  *
- *
  * THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY EXPRESSED
  * OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.
  *
@@ -412,9 +459,14 @@ AO_fetch_and_add_acquire(volatile AO_t *addr, AO_t incr)
  * Permission to modify the code and to distribute modified code is granted,
  * provided the above notices are retained, and a notice that the code was
  * modified is included with the above copyright notice.
- *
  */
 
+#if !defined(AO_ATOMIC_OPS_H) || defined(AO_ATOMIC_OPS_INCLUDED)
+# error This file should not be included directly.
+#endif
+
+#ifndef AO_NO_char_ARITHM
+
 AO_INLINE unsigned/**/char
 AO_char_fetch_and_add_release(volatile unsigned/**/char *addr, unsigned/**/char incr)
 {
@@ -448,12 +500,13 @@ AO_char_fetch_and_add_release(volatile unsigned/**/char *addr, unsigned/**/char
   }
 # define AO_HAVE_char_xor_release
 #endif
+
+#endif /* !AO_NO_char_ARITHM */
 /*
  * Copyright (c) 1991-1994 by Xerox Corporation.  All rights reserved.
  * Copyright (c) 1996-1999 by Silicon Graphics.  All rights reserved.
  * Copyright (c) 2003-2011 Hewlett-Packard Development Company, L.P.
  *
- *
  * THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY EXPRESSED
  * OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.
  *
@@ -462,9 +515,14 @@ AO_char_fetch_and_add_release(volatile unsigned/**/char *addr, unsigned/**/char
  * Permission to modify the code and to distribute modified code is granted,
  * provided the above notices are retained, and a notice that the code was
  * modified is included with the above copyright notice.
- *
  */
 
+#if !defined(AO_ATOMIC_OPS_H) || defined(AO_ATOMIC_OPS_INCLUDED)
+# error This file should not be included directly.
+#endif
+
+#ifndef AO_NO_short_ARITHM
+
 AO_INLINE unsigned/**/short
 AO_short_fetch_and_add_release(volatile unsigned/**/short *addr, unsigned/**/short incr)
 {
@@ -498,12 +556,13 @@ AO_short_fetch_and_add_release(volatile unsigned/**/short *addr, unsigned/**/sho
   }
 # define AO_HAVE_short_xor_release
 #endif
+
+#endif /* !AO_NO_short_ARITHM */
 /*
  * Copyright (c) 1991-1994 by Xerox Corporation.  All rights reserved.
  * Copyright (c) 1996-1999 by Silicon Graphics.  All rights reserved.
  * Copyright (c) 2003-2011 Hewlett-Packard Development Company, L.P.
  *
- *
  * THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY EXPRESSED
  * OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.
  *
@@ -512,9 +571,14 @@ AO_short_fetch_and_add_release(volatile unsigned/**/short *addr, unsigned/**/sho
  * Permission to modify the code and to distribute modified code is granted,
  * provided the above notices are retained, and a notice that the code was
  * modified is included with the above copyright notice.
- *
  */
 
+#if !defined(AO_ATOMIC_OPS_H) || defined(AO_ATOMIC_OPS_INCLUDED)
+# error This file should not be included directly.
+#endif
+
+#ifndef AO_NO_int_ARITHM
+
 AO_INLINE unsigned
 AO_int_fetch_and_add_release(volatile unsigned *addr, unsigned incr)
 {
@@ -548,12 +612,13 @@ AO_int_fetch_and_add_release(volatile unsigned *addr, unsigned incr)
   }
 # define AO_HAVE_int_xor_release
 #endif
+
+#endif /* !AO_NO_int_ARITHM */
 /*
  * Copyright (c) 1991-1994 by Xerox Corporation.  All rights reserved.
  * Copyright (c) 1996-1999 by Silicon Graphics.  All rights reserved.
  * Copyright (c) 2003-2011 Hewlett-Packard Development Company, L.P.
  *
- *
  * THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY EXPRESSED
  * OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.
  *
@@ -562,9 +627,14 @@ AO_int_fetch_and_add_release(volatile unsigned *addr, unsigned incr)
  * Permission to modify the code and to distribute modified code is granted,
  * provided the above notices are retained, and a notice that the code was
  * modified is included with the above copyright notice.
- *
  */
 
+#if !defined(AO_ATOMIC_OPS_H) || defined(AO_ATOMIC_OPS_INCLUDED)
+# error This file should not be included directly.
+#endif
+
+#ifndef AO_NO_ARITHM
+
 AO_INLINE AO_t
 AO_fetch_and_add_release(volatile AO_t *addr, AO_t incr)
 {
@@ -598,12 +668,13 @@ AO_fetch_and_add_release(volatile AO_t *addr, AO_t incr)
   }
 # define AO_HAVE_xor_release
 #endif
+
+#endif /* !AO_NO_ARITHM */
 /*
  * Copyright (c) 1991-1994 by Xerox Corporation.  All rights reserved.
  * Copyright (c) 1996-1999 by Silicon Graphics.  All rights reserved.
  * Copyright (c) 2003-2011 Hewlett-Packard Development Company, L.P.
  *
- *
  * THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY EXPRESSED
  * OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.
  *
@@ -612,9 +683,14 @@ AO_fetch_and_add_release(volatile AO_t *addr, AO_t incr)
  * Permission to modify the code and to distribute modified code is granted,
  * provided the above notices are retained, and a notice that the code was
  * modified is included with the above copyright notice.
- *
  */
 
+#if !defined(AO_ATOMIC_OPS_H) || defined(AO_ATOMIC_OPS_INCLUDED)
+# error This file should not be included directly.
+#endif
+
+#ifndef AO_NO_char_ARITHM
+
 AO_INLINE unsigned/**/char
 AO_char_fetch_and_add_full(volatile unsigned/**/char *addr, unsigned/**/char incr)
 {
@@ -648,12 +724,13 @@ AO_char_fetch_and_add_full(volatile unsigned/**/char *addr, unsigned/**/char inc
   }
 # define AO_HAVE_char_xor_full
 #endif
+
+#endif /* !AO_NO_char_ARITHM */
 /*
  * Copyright (c) 1991-1994 by Xerox Corporation.  All rights reserved.
  * Copyright (c) 1996-1999 by Silicon Graphics.  All rights reserved.
  * Copyright (c) 2003-2011 Hewlett-Packard Development Company, L.P.
  *
- *
  * THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY EXPRESSED
  * OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.
  *
@@ -662,9 +739,14 @@ AO_char_fetch_and_add_full(volatile unsigned/**/char *addr, unsigned/**/char inc
  * Permission to modify the code and to distribute modified code is granted,
  * provided the above notices are retained, and a notice that the code was
  * modified is included with the above copyright notice.
- *
  */
 
+#if !defined(AO_ATOMIC_OPS_H) || defined(AO_ATOMIC_OPS_INCLUDED)
+# error This file should not be included directly.
+#endif
+
+#ifndef AO_NO_short_ARITHM
+
 AO_INLINE unsigned/**/short
 AO_short_fetch_and_add_full(volatile unsigned/**/short *addr, unsigned/**/short incr)
 {
@@ -698,12 +780,13 @@ AO_short_fetch_and_add_full(volatile unsigned/**/short *addr, unsigned/**/short
   }
 # define AO_HAVE_short_xor_full
 #endif
+
+#endif /* !AO_NO_short_ARITHM */
 /*
  * Copyright (c) 1991-1994 by Xerox Corporation.  All rights reserved.
  * Copyright (c) 1996-1999 by Silicon Graphics.  All rights reserved.
  * Copyright (c) 2003-2011 Hewlett-Packard Development Company, L.P.
  *
- *
  * THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY EXPRESSED
  * OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.
  *
@@ -712,9 +795,14 @@ AO_short_fetch_and_add_full(volatile unsigned/**/short *addr, unsigned/**/short
  * Permission to modify the code and to distribute modified code is granted,
  * provided the above notices are retained, and a notice that the code was
  * modified is included with the above copyright notice.
- *
  */
 
+#if !defined(AO_ATOMIC_OPS_H) || defined(AO_ATOMIC_OPS_INCLUDED)
+# error This file should not be included directly.
+#endif
+
+#ifndef AO_NO_int_ARITHM
+
 AO_INLINE unsigned
 AO_int_fetch_and_add_full(volatile unsigned *addr, unsigned incr)
 {
@@ -748,12 +836,13 @@ AO_int_fetch_and_add_full(volatile unsigned *addr, unsigned incr)
   }
 # define AO_HAVE_int_xor_full
 #endif
+
+#endif /* !AO_NO_int_ARITHM */
 /*
  * Copyright (c) 1991-1994 by Xerox Corporation.  All rights reserved.
  * Copyright (c) 1996-1999 by Silicon Graphics.  All rights reserved.
  * Copyright (c) 2003-2011 Hewlett-Packard Development Company, L.P.
  *
- *
  * THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY EXPRESSED
  * OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.
  *
@@ -762,9 +851,14 @@ AO_int_fetch_and_add_full(volatile unsigned *addr, unsigned incr)
  * Permission to modify the code and to distribute modified code is granted,
  * provided the above notices are retained, and a notice that the code was
  * modified is included with the above copyright notice.
- *
  */
 
+#if !defined(AO_ATOMIC_OPS_H) || defined(AO_ATOMIC_OPS_INCLUDED)
+# error This file should not be included directly.
+#endif
+
+#ifndef AO_NO_ARITHM
+
 AO_INLINE AO_t
 AO_fetch_and_add_full(volatile AO_t *addr, AO_t incr)
 {
@@ -798,3 +892,5 @@ AO_fetch_and_add_full(volatile AO_t *addr, AO_t incr)
   }
 # define AO_HAVE_xor_full
 #endif
+
+#endif /* !AO_NO_ARITHM */
